==> maven-dependency-plugin-3.9.0-source-release.zip: maven-dependency-plugin-3.9.0/src/test/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependenciesMojoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.dependency.resolvers;

import java.io.IOException;
import java.util.HashSet;
import java.util.Set;

import org.apache.maven.artifact.Artifact;
import org.apache.maven.artifact.versioning.VersionRange;
import org.apache.maven.plugins.dependency.AbstractDependencyMojoTestCase;
import org.apache.maven.plugins.dependency.utils.DependencyStatusSets;

public class ResolveDependenciesMojoTest extends AbstractDependencyMojoTestCase {

    @Override
    protected String getTestDirectoryName() {
        return "dss";
    }

    @Override
    protected boolean shouldCreateFiles() {
        return true;
    }

    @Override
    protected void setUp() throws Exception {
        // required for mojo lookups to work
        super.setUp();
    }

    public void testDependencyStatusLog() throws IOException {
        Set<Artifact> artifacts = this.stubFactory.getMixedArtifacts();
        doTestDependencyStatusLog(artifacts);
    }

    public void testDependencyStatusLogNullFiles() throws IOException {
        this.stubFactory.setCreateFiles(false);
        Set<Artifact> artifacts = this.stubFactory.getMixedArtifacts();
        doTestDependencyStatusLog(artifacts);
    }

    public void testDependencyStatusEmptySet() {
        doTestDependencyStatusLog(new HashSet<>());
    }

    public void testOptionalDependencyFormatting() throws IOException {
        Set<Artifact> set = new HashSet<>();
        Artifact artifact =
                stubFactory.createArtifact("g", "a", VersionRange.createFromVersion("1.0"), "test", "jar", null, true);
        set.add(artifact);
        doTestDependencyStatusLog(set);
        ResolveDependenciesMojo mojo = newMojo(new DependencyStatusSets());
        mojo.results.setResolvedDependencies(set);
        String output = mojo.getOutput(false, true, false);
        assertTrue(output.contains("g:a:jar:1.0:test (optional)" + System.lineSeparator()));
    }

    private void doTestDependencyStatusLog(Set<Artifact> artifacts) {
        // this test is just looking for unexpected exceptions.

        ResolveDependenciesMojo mojo = newMojo(new DependencyStatusSets());
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, null, null));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(null, artifacts, null));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(null, null, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, artifacts, null));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(null, artifacts, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, null, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, artifacts, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);
        mojo.getOutput(false, false, false);
        mojo.getOutput(true, false, false);
    }

    private ResolveDependenciesMojo newMojo(final DependencyStatusSets dss) {
        ResolveDependenciesMojo mojo = new ResolveDependenciesMojo(null, null, null, null, null, null);
        mojo.results = dss;
        return mojo;
    }
}

==> maven-dependency-plugin-3.10.0-source-release.zip: maven-dependency-plugin-3.10.0/src/test/java/org/apache/maven/plugins/dependency/resolvers/ResolveDependenciesMojoTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.plugins.dependency.resolvers;

import java.io.IOException;
import java.util.HashSet;
import java.util.Set;

import org.apache.maven.artifact.Artifact;
import org.apache.maven.artifact.versioning.VersionRange;
import org.apache.maven.plugins.dependency.testUtils.DependencyArtifactStubFactory;
import org.apache.maven.plugins.dependency.utils.DependencyStatusSets;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertTrue;

class ResolveDependenciesMojoTest {

    private DependencyArtifactStubFactory stubFactory;

    @BeforeEach
    void setUp() {
        stubFactory = new DependencyArtifactStubFactory(null, false, false);
    }

    @Test
    void testDependencyStatusLog() throws IOException {
        Set<Artifact> artifacts = this.stubFactory.getMixedArtifacts();
        doTestDependencyStatusLog(artifacts);
    }

    @Test
    void testDependencyStatusLogNullFiles() throws IOException {
        this.stubFactory.setCreateFiles(false);
        Set<Artifact> artifacts = this.stubFactory.getMixedArtifacts();
        doTestDependencyStatusLog(artifacts);
    }

    @Test
    void testDependencyStatusEmptySet() {
        doTestDependencyStatusLog(new HashSet<>());
    }

    @Test
    void testOptionalDependencyFormatting() throws IOException {
        Set<Artifact> set = new HashSet<>();
        Artifact artifact =
                stubFactory.createArtifact("g", "a", VersionRange.createFromVersion("1.0"), "test", "jar", null, true);
        set.add(artifact);
        doTestDependencyStatusLog(set);
        ResolveDependenciesMojo mojo = newMojo(new DependencyStatusSets());
        mojo.results.setResolvedDependencies(set);
        String output = mojo.getOutput(false, true, false);
        assertTrue(output.contains("g:a:jar:1.0:test (optional)" + System.lineSeparator()));
    }

    private void doTestDependencyStatusLog(Set<Artifact> artifacts) {
        // this test is just looking for unexpected exceptions.

        ResolveDependenciesMojo mojo = newMojo(new DependencyStatusSets());
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, null, null));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(null, artifacts, null));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(null, null, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, artifacts, null));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(null, artifacts, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, null, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);

        mojo = newMojo(new DependencyStatusSets(artifacts, artifacts, artifacts));
        mojo.getOutput(false, true, false);
        mojo.getOutput(true, true, false);
        mojo.getOutput(false, false, false);
        mojo.getOutput(true, false, false);
    }

    private ResolveDependenciesMojo newMojo(final DependencyStatusSets dss) {
        ResolveDependenciesMojo mojo = new ResolveDependenciesMojo(null, null, null, null, null, null);
        mojo.results = dss;
        return mojo;
    }
}
